.. pymadng documentation master file, created by
   sphinx-quickstart on Mon Nov 28 12:54:22 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation for PyMAD-NG!
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   gettingstarted
   modules
   ex-lowlevel
   ex-managing-refs
   ex-fodo
   ex-recv-lhc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
